initialize method

Future<void> initialize({
  1. List<int>? ageGates,
  2. bool useMockData = false,
  3. AgeSignalsMockData? mockData,
})

Initializes the plugin with platform-specific configuration.

ageGates specifies the age thresholds. iOS requires them; Play ignores them, but Android uses the highest gate as the bar for verified, using 18 until you supply gates and keeping them if a later call omits them. For example, 13, 16, 18 will allow the app to determine if the user is under 13, between 13-15, between 16-17, or 18+.

Set useMockData to true to use fake/test data instead of real APIs. This is useful for testing before APIs are available or in development. When useMockData is true, you can optionally provide mockData to customize the mock response. If not provided, default mock data will be used.

Should be called before checkAgeSignals.

Implementation

Future<void> initialize({
  List<int>? ageGates,
  bool useMockData = false,
  AgeSignalsMockData? mockData,
}) {
  throw UnimplementedError('initialize() has not been implemented.');
}