AgeSignalsException class
Base exception for age signals operations.
Constructors
- AgeSignalsException(String message, [String? code, String? details])
-
Creates an AgeSignalsException.
const
Properties
- code → String?
-
An optional error code.
final
- details → String?
-
Optional detailed diagnostic information.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
A description of the error.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited